
/*===============================================================================
Title: ArduinoLeonardoSkywire.ino
Description: Arduino Leonardo with Skywire Module

Copyright (c)2014, 2015 ILS Technology.
http://www.ilstechnology.com
http://www.devicewise.com


Legal Disclaimer:

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:

    Neither the name of ILS Technology nor Telit nor the names of its
    contributors may be used to endorse or promote products derived
    from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

===================================================================================*/

#include <dwOpenClient.h>

// Authentication/Registration Details      
#define DWOPEN_APPTOKEN    "1kagVL7HGh6JAd9w"      //Application Token
#define DWOPEN_SERVER      "api.devicewise.com"    //deviceWISE server
#define DWOPEN_PORT        1883                    //MQTT Port

//ILST Headquarters - GPS Detail...
#define ILST_Latitude      "26.394919"
#define ILST_Longitude     "-80.112808"
#define ILST_Altitude      "3.0"
#define ILST_Speed         "0.0"
#define ILST_Heading       "0.0"

dwOpenClient dwClient( (char *) DWOPEN_SERVER, DWOPEN_PORT, (char *) DWOPEN_APPTOKEN ); 


// code that initializes the serial ports and modem, waits for valid network connection
void setup() 
{
 int i;
   
  //Initialize serial for screen print
  Serial.begin(9600);
  delay(3000);
  
  //Delay start of execution to allow user to setup debug print
  for(i = 3; i > 0; i-- )
  {
    Serial.print("Ready to Execute... Countdown = ");
    Serial.println(i); 
    delay( 1000 );
  }
  
}


// main loop that sends the SMS message
void loop() 
{
  static int i = 0, j = 0;
  int rcode;
  

  if ( !dwClient.isConnected() )
  {  
      rcode = dwClient.dwDeviceConnect();

      if ( rcode )
      {
        Serial.println("Connection Error...");
      }
      else
      {
        Serial.println("Connected to m2mAIR Cloud...");
  
        // Publish Log Message... Connected
        Serial.println("dwLaunchPad- Log Publish In Process..." );
        rcode = dwClient.dwLogPublish( "deviceWISE Demo Program Started...");        

        // Publish Sample Attribute Data... 
        Serial.println("dwLaunchPad- Attribute Publish In Process..." );
        rcode = dwClient.dwAttributePublish( "attr1", "Attribute 1 Details" );   
        
        // Publish Location Data...
        Serial.println("dwOpen API - Location Publish In Process..." );      
        rcode = dwClient.dwLocationPublish( ILST_Latitude, ILST_Longitude, ILST_Altitude, ILST_Speed, ILST_Heading );     
               
      }
  }

    
  if ( dwClient.isConnected() )
  {
      dwClient.dwPropertyPublish( "StepUp", i++ );
      dwClient.dwPropertyPublish( "StepDown", j-- );
      
  }

  
  Serial.println("Sleeping for 5 seconds...");
  delay(5000);
    
}



