/*
  dwOpenClient.cpp - MQTT dwOpen Client Library

*/

#include "dwOpenClient.h"


dwOpenClient::dwOpenClient(char *Server, int Port, char *AppToken ) 
{
   this->Server = Server;
   this->Port = Port;
   this->AppToken = AppToken;
   this->connected = false;   
   this->connectionGood = false;
}

void dwOpenClient::resetMODEM(void)
{
  //Initialize serial port to communicate with modem
  Serial.println("Reseting MODEM");
    
  // Arduino I/O pin 12 is connected to modem ON_OFF signal.
  // ON_OFF has internal 200k pullup resister and needs to be driven low by external signal for >1s to startup
  // Arduino defaults to I/O pin as input with no pullup on reset
  // Set I/O pin 12 to low
  digitalWrite(12, LOW);
  
  // Configure I/O pin 12 as output
  pinMode(12, OUTPUT);
  
  // Drive I/O pin 12 low
  digitalWrite(12, LOW);
  delay(1100); // modem requires >1s pulse

  // Return I/O pin 12 to input/hi-Z state  
  pinMode(12, INPUT);

  //Start the I/F to the Telit Module
  Serial.println("Initializing modem COM port");  
  Serial1.begin(115200);
  while( !Serial1 ) ;  
  
}



int dwOpenClient::sendATCommand( char *SendData )
{
    int i = 0;
    int z;
    char ch;

    Serial.println( SendData );
    
    memset( RespData, 0, sizeof(RespData) );
    
    //flush input if anything is present...    
    while(Serial1.available() >0) Serial1.read();  
    
    //Send data to MODEM
    Serial1.println( SendData );

    //Allow time for command processing/response
    delay(100);

    //get MODEM Echo response...    
    while(Serial1.available() >0) 
    {      
        ch = Serial1.read();
        
        if ( ch == '\r' ) break;
        else RespData[i++] = ch;            
    }     
        
    if ( !strncmp( SendData, RespData, strlen(SendData) ) )
    {
        //Get AT command Response
        memset( RespData, 0, sizeof(RespData) );    
    
        //get MODEM response...    

        for ( z = 0; z < 20; z++ )
        {           
            int i = 0;
            while(Serial1.available() >0) {
                ch = Serial1.read();
    
                if ( (ch != '\r') && (ch != '\n' ) )
                {
                    RespData[i++] = ch;
                }
            }

            if ( i ) break;
            
            delay(1000);
        }             
    }
       
  return 0;
}

bool dwOpenClient::isConnected(void)
{
	return(this->connected);
}

bool dwOpenClient::connectionStatus(void)
{
  sendATCommand("AT#DWSTATUS" );
  Serial.println(RespData);  
}

int dwOpenClient::dwDeviceConnect(void)
{  

  //Configure MODEM interface
  resetMODEM();

  //Get MODEM firmware version
  sendATCommand("AT+CGSN");
  
  if ( strlen(RespData) == 0 )
  {
	  return(1);
  }
  
  Serial.println(RespData);  
   
  //Turn off PDP Context if it was previously ON
  sendATCommand("AT#SGACT=1,0" );
  Serial.println(RespData);
  
  //PDP Context Activation 
  sendATCommand("AT#SGACT=1,1" );
  
  if ( (strlen(RespData) == 0) || (!strcmp(RespData, "ERROR") ) )
  {
	  return(1);
  }
  
  Serial.println(RespData);
  
  Serial.println("Waiting for network connection"); 
  
  while(!connectionGood)
  {    
    // Get network status
    sendATCommand("AT+CREG?");
    Serial.println(RespData);     
    
    // check Response to see if network status is "0,1" or "0,5" which means we are connected
    if ( (strstr(RespData,"0,1")) || (strstr(RespData, "0,5")) )
    {
        connectionGood = true;
        Serial.println(); 
        Serial.println("Connection successful!");  

		sprintf(ATCommand, "AT#DWCFG=%s,0,%s", this->Server, this->AppToken);		
        sendATCommand(ATCommand);
        Serial.println(RespData);
        
        sendATCommand("AT#DWCONN=0" );
        Serial.println(RespData);
            
        sendATCommand("AT#DWCONN=1" );
        Serial.println(RespData); 

		this->connected = true;
		
        return(0);
    }    
  }

  //didn't connect
  this->connected = false;
  
  return(1);
}


int dwOpenClient::dwPropertyPublish( char *Key, int Value )
{
  sprintf(ATCommand, "AT#DWSEND=0,property.publish,key,%s,value,%d\r", Key, Value);

  sendATCommand(ATCommand);
  
  Serial.println(RespData);      
}

int dwOpenClient::dwAttributePublish( char *Key, char *Value )
{
  sprintf(ATCommand, "AT#DWSEND=0,thing.attr.set,key,%s,value,%s\r", Key, Value);  

  sendATCommand(ATCommand);
  
  Serial.println(RespData);      
}

int dwOpenClient::dwLogPublish( char *Message )
{
  sprintf(ATCommand, "AT#DWSEND=0,log.publish,global,0,msg,\"%s\"\r", Message);

  sendATCommand(ATCommand);
  
  Serial.println(RespData);      
}

int dwOpenClient::dwLocationPublish( char *Lat, char *Lng, char *Alt, char *Spd, char *Head )
{
 
	sprintf(ATCommand, "AT#DWSEND=0,location.publish,lat,%s,lng,%s,heading,%s,altitude,%s,speed,%s\r", Lat, Lng, Head, Alt, Spd);

	sendATCommand(ATCommand);

	Serial.println(RespData);      
}
